.. :changelog:

Shiba : Python API for PriceMinister WebServices
================================================

Version 1.1.9
-------------

Released on December 15th 2016

- Used furl to manipulate URLs

Version 1.1.8
-------------

Released on December 14th 2016

- Fix encoding in urlencode

Version 1.1.7
-------------

Released on November 08th 2016

- Fix broken pypi package

Version 1.1.6
-------------

Released on August 10th 2016

- Updated the webservices versions

Version 1.1.5
-------------

Released on July 21st 2016

- Python 3 support
